summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--remoting/host/desktop_environment.cc4
-rw-r--r--remoting/host/session_event_executor_win.cc4
-rw-r--r--remoting/host/wts_session_process_launcher_win.cc2
-rw-r--r--remoting/remoting.gyp27
4 files changed, 12 insertions, 25 deletions
diff --git a/remoting/host/desktop_environment.cc b/remoting/host/desktop_environment.cc
index 0007c8a..43ed501 100644
--- a/remoting/host/desktop_environment.cc
+++ b/remoting/host/desktop_environment.cc
@@ -11,7 +11,7 @@
#include "remoting/host/chromoting_host_context.h"
#include "remoting/host/event_executor.h"
-#if defined(OS_WIN)
+#if defined(USE_CHROMOTING_IPC)
#include "remoting/host/session_event_executor_win.h"
#endif
@@ -30,7 +30,7 @@ scoped_ptr<DesktopEnvironment> DesktopEnvironment::Create(
return scoped_ptr<DesktopEnvironment>();
}
-#if defined(OS_WIN)
+#if defined(USE_CHROMOTING_IPC)
event_executor.reset(new SessionEventExecutorWin(
context->desktop_message_loop(),
context->io_message_loop(),
diff --git a/remoting/host/wts_session_process_launcher_win.cc b/remoting/host/wts_session_process_launcher_win.cc
index fa8b2b2..45d81cf 100644
--- a/remoting/host/wts_session_process_launcher_win.cc
+++ b/remoting/host/wts_session_process_launcher_win.cc
@@ -44,7 +44,7 @@ const char kDefaultDesktopName[] = "winsta0\\default";
const char kChromePipeNamePrefix[] = "\\\\.\\pipe\\chrome.";
// Generates the command line of the host process.
-const char kHostProcessCommandLineFormat[] = "\"%ls\" --channel=%ls";
+const char kHostProcessCommandLineFormat[] = "\"%ls\" --chromoting-ipc=%ls";
// The security descriptor of the Chromoting IPC channel. It gives full access
// to LocalSystem and denies access by anyone else.
diff --git a/remoting/remoting.gyp b/remoting/remoting.gyp
index adc4934..8992f30 100644
--- a/remoting/remoting.gyp
+++ b/remoting/remoting.gyp
@@ -340,11 +340,6 @@
}],
], # conditions
}], # OS=="mac"
- [ 'OS=="win"', {
- 'dependencies': [
- '../ipc/ipc.gyp:ipc'
- ],
- }],
['OS!="win"', {
'sources!': [
'host/plugin/host_plugin.def',
@@ -582,8 +577,6 @@
'host/screen_recorder.h',
'host/server_log_entry.cc',
'host/server_log_entry.h',
- 'host/session_event_executor_win.cc',
- 'host/session_event_executor_win.h',
'host/signaling_connector.cc',
'host/signaling_connector.h',
'host/ui_strings.cc',
@@ -699,13 +692,6 @@
'host/it2me_host_user_interface.h',
'host/simple_host_process.cc',
],
- 'conditions': [
- ['OS=="win"', {
- 'dependencies': [
- '../ipc/ipc.gyp:ipc'
- ],
- }],
- ],
}, # end of target 'remoting_simple_host'
{
@@ -729,7 +715,7 @@
'sources': [
'host/host_event_logger_posix.cc',
],
- }],
+ }],
['OS=="win"', {
'dependencies': [
'../ipc/ipc.gyp:ipc'
@@ -737,10 +723,16 @@
'sources': [
'host/host_event_logger_win.cc',
'host/remoting_host_messages.mc',
+ 'host/session_event_executor_win.cc',
+ 'host/session_event_executor_win.h',
],
'include_dirs': [
'<(INTERMEDIATE_DIR)',
],
+ # Allow the host to connect to the remoting service.
+ 'defines': [
+ 'USE_CHROMOTING_IPC',
+ ],
# Rule to run the message compiler.
'rules': [
{
@@ -1039,11 +1031,6 @@
'run_all_unittests.cc',
],
'conditions': [
- [ 'OS=="win"', {
- 'dependencies': [
- '../ipc/ipc.gyp:ipc'
- ],
- }],
['chromeos == 0', {
'dependencies': [
'remoting_host'
diff --git a/remoting/host/session_event_executor_win.cc b/remoting/host/session_event_executor_win.cc
index 36e5056..31eccff 100644
--- a/remoting/host/session_event_executor_win.cc
+++ b/remoting/host/session_event_executor_win.cc
@@ -19,8 +19,8 @@
namespace {
-// The command line switch specifying the name of the session IPC channel.
-const char kProcessChannelId[] = "channel";
+// The command line switch specifying the name of the Chromoting IPC channel.
+const char kProcessChannelId[] = "chromoting-ipc";
} // namespace